# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: healthbot-hackers@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from jnpr.healthbot.swagger.models.rule_schema_byoi import RuleSchemaByoi  # noqa: F401,E501
from jnpr.healthbot.swagger.models.rule_schema_flow import RuleSchemaFlow  # noqa: F401,E501
from jnpr.healthbot.swagger.models.rule_schema_i_agent import RuleSchemaIAgent  # noqa: F401,E501
from jnpr.healthbot.swagger.models.rule_schema_nativegpb import RuleSchemaNativegpb  # noqa: F401,E501
from jnpr.healthbot.swagger.models.rule_schema_openconfig import RuleSchemaOpenconfig  # noqa: F401,E501
from jnpr.healthbot.swagger.models.rule_schema_snmp import RuleSchemaSnmp  # noqa: F401,E501
from jnpr.healthbot.swagger.models.rule_schema_syslog import RuleSchemaSyslog  # noqa: F401,E501


class RuleSchemaSensor1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'flow': 'RuleSchemaFlow',
        'i_agent': 'RuleSchemaIAgent',
        'native_gpb': 'RuleSchemaNativegpb',
        'open_config': 'RuleSchemaOpenconfig',
        'sensor_name': 'str',
        'snmp': 'RuleSchemaSnmp',
        'syslog': 'RuleSchemaSyslog',
        'synopsis': 'str',
        'byoi': 'RuleSchemaByoi'
    }

    attribute_map = {
        'description': 'description',
        'flow': 'flow',
        'i_agent': 'iAgent',
        'native_gpb': 'native-gpb',
        'open_config': 'open-config',
        'sensor_name': 'sensor-name',
        'snmp': 'snmp',
        'syslog': 'syslog',
        'synopsis': 'synopsis',
        'byoi': 'byoi'
    }

    def __init__(self, description=None, flow=None, i_agent=None, native_gpb=None, open_config=None, sensor_name=None, snmp=None, syslog=None, synopsis=None, byoi=None):  # noqa: E501
        """RuleSchemaSensor1 - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._flow = None
        self._i_agent = None
        self._native_gpb = None
        self._open_config = None
        self._sensor_name = None
        self._snmp = None
        self._syslog = None
        self._synopsis = None
        self._byoi = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if flow is not None:
            self.flow = flow
        if i_agent is not None:
            self.i_agent = i_agent
        if native_gpb is not None:
            self.native_gpb = native_gpb
        if open_config is not None:
            self.open_config = open_config
        self.sensor_name = sensor_name
        if snmp is not None:
            self.snmp = snmp
        if syslog is not None:
            self.syslog = syslog
        if synopsis is not None:
            self.synopsis = synopsis
        if byoi is not None:
            self.byoi = byoi

    @property
    def description(self):
        """Gets the description of this RuleSchemaSensor1.  # noqa: E501

        Description about the sensor  # noqa: E501

        :return: The description of this RuleSchemaSensor1.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RuleSchemaSensor1.

        Description about the sensor  # noqa: E501

        :param description: The description of this RuleSchemaSensor1.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def flow(self):
        """Gets the flow of this RuleSchemaSensor1.  # noqa: E501


        :return: The flow of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this RuleSchemaSensor1.


        :param flow: The flow of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaFlow
        """

        self._flow = flow

    @property
    def i_agent(self):
        """Gets the i_agent of this RuleSchemaSensor1.  # noqa: E501


        :return: The i_agent of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaIAgent
        """
        return self._i_agent

    @i_agent.setter
    def i_agent(self, i_agent):
        """Sets the i_agent of this RuleSchemaSensor1.


        :param i_agent: The i_agent of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaIAgent
        """

        self._i_agent = i_agent

    @property
    def native_gpb(self):
        """Gets the native_gpb of this RuleSchemaSensor1.  # noqa: E501


        :return: The native_gpb of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaNativegpb
        """
        return self._native_gpb

    @native_gpb.setter
    def native_gpb(self, native_gpb):
        """Sets the native_gpb of this RuleSchemaSensor1.


        :param native_gpb: The native_gpb of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaNativegpb
        """

        self._native_gpb = native_gpb

    @property
    def open_config(self):
        """Gets the open_config of this RuleSchemaSensor1.  # noqa: E501


        :return: The open_config of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaOpenconfig
        """
        return self._open_config

    @open_config.setter
    def open_config(self, open_config):
        """Sets the open_config of this RuleSchemaSensor1.


        :param open_config: The open_config of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaOpenconfig
        """

        self._open_config = open_config

    @property
    def sensor_name(self):
        """Gets the sensor_name of this RuleSchemaSensor1.  # noqa: E501

        Name of sensor. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The sensor_name of this RuleSchemaSensor1.  # noqa: E501
        :rtype: str
        """
        return self._sensor_name

    @sensor_name.setter
    def sensor_name(self, sensor_name):
        """Sets the sensor_name of this RuleSchemaSensor1.

        Name of sensor. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param sensor_name: The sensor_name of this RuleSchemaSensor1.  # noqa: E501
        :type: str
        """
        if sensor_name is None:
            raise ValueError("Invalid value for `sensor_name`, must not be `None`")  # noqa: E501
        if sensor_name is not None and len(sensor_name) > 64:
            raise ValueError("Invalid value for `sensor_name`, length must be less than or equal to `64`")  # noqa: E501
        if sensor_name is not None and not re.search('^[a-zA-Z][a-zA-Z0-9_-]*$', sensor_name):  # noqa: E501
            raise ValueError("Invalid value for `sensor_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._sensor_name = sensor_name

    @property
    def snmp(self):
        """Gets the snmp of this RuleSchemaSensor1.  # noqa: E501


        :return: The snmp of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaSnmp
        """
        return self._snmp

    @snmp.setter
    def snmp(self, snmp):
        """Sets the snmp of this RuleSchemaSensor1.


        :param snmp: The snmp of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaSnmp
        """

        self._snmp = snmp

    @property
    def syslog(self):
        """Gets the syslog of this RuleSchemaSensor1.  # noqa: E501


        :return: The syslog of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaSyslog
        """
        return self._syslog

    @syslog.setter
    def syslog(self, syslog):
        """Sets the syslog of this RuleSchemaSensor1.


        :param syslog: The syslog of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaSyslog
        """

        self._syslog = syslog

    @property
    def synopsis(self):
        """Gets the synopsis of this RuleSchemaSensor1.  # noqa: E501

        Synopsis about the sensor  # noqa: E501

        :return: The synopsis of this RuleSchemaSensor1.  # noqa: E501
        :rtype: str
        """
        return self._synopsis

    @synopsis.setter
    def synopsis(self, synopsis):
        """Sets the synopsis of this RuleSchemaSensor1.

        Synopsis about the sensor  # noqa: E501

        :param synopsis: The synopsis of this RuleSchemaSensor1.  # noqa: E501
        :type: str
        """

        self._synopsis = synopsis

    @property
    def byoi(self):
        """Gets the byoi of this RuleSchemaSensor1.  # noqa: E501


        :return: The byoi of this RuleSchemaSensor1.  # noqa: E501
        :rtype: RuleSchemaByoi
        """
        return self._byoi

    @byoi.setter
    def byoi(self, byoi):
        """Sets the byoi of this RuleSchemaSensor1.


        :param byoi: The byoi of this RuleSchemaSensor1.  # noqa: E501
        :type: RuleSchemaByoi
        """

        self._byoi = byoi

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaSensor1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import requests
from requests.models import Response
from requests.exceptions import HTTPError
import logging

import re
import os
import time
import jwt
from jnpr.healthbot.exception import ConnectAuthError
from jnpr.healthbot.modules import devices
from jnpr.healthbot.modules import rules
from jnpr.healthbot.modules import playbooks
from jnpr.healthbot.modules import database
from jnpr.healthbot.modules import settings
from jnpr.healthbot.modules import profiles
from jnpr.healthbot.modules import graph
from jnpr.healthbot.modules import BaseModule

from jnpr.healthbot.swagger.api.authentication_api import AuthenticationApi
from jnpr.healthbot.swagger.api_client import ApiClient
from jnpr.healthbot.swagger.configuration import Configuration
from jnpr.healthbot.swagger.models.health_schema import HealthSchema
from jnpr.healthbot.swagger.models.refresh_token import RefreshToken
from jnpr.healthbot.swagger.models.token import Token

from jnpr.healthbot.swagger.api.configuration_api import ConfigurationApi
from jnpr.healthbot.swagger.api.default_api import DefaultApi
from jnpr.healthbot.swagger.api.authentication_api import AuthenticationApi
from jnpr.healthbot.swagger.api.data_source_api import DataSourceApi
from jnpr.healthbot.swagger.api.data_store_api import DataStoreApi
from jnpr.healthbot.swagger.api.debug_api import DebugApi
from jnpr.healthbot.swagger.api.instance_schedule_state_api import InstanceScheduleStateApi
from jnpr.healthbot.swagger.api.license_api import LicenseApi
from jnpr.healthbot.swagger.api.services_api import ServicesApi
from jnpr.healthbot.swagger.api.system_api import SystemApi

from jnpr.healthbot.swagger.rest import ApiException
from jnpr.healthbot.urlfor import UrlFor

from pathlib import Path

import urllib3
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


logger = logging.getLogger(__file__)


class HealthBotClient(object):

    apiopt_candidate = "/?working=true"

    def __init__(
            self,
            server: str,
            user: str,
            password: str,
            *args, **kwargs):
        """
        An instance of this class represents the HealthBot Service

        :param str server: HealthBot Server IP Address
        :param str user: HealthBot Server (not the Linux user) UserName
        :param str password: HealthBot Server (not the Linux user) password
        :param int port: *OPTIONAL* HealthBot Server port (defaults to 8080)

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from pprint import pprint

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx', port=8000) as hb:

                # Get list of all existing devices
                print(hb.device.get_ids())

                # Get config details of a given device id
                pprint(hb.device.get('core-01'))

                # Get config details of all the device
                pprint(hb.device.get())

                # Get device facts of a given device id
                pprint(hb.device.get_facts('avro'))

                # Get device facts for all the devices in HB
                pprint(hb.device.get_facts())

                # Add a device
                from jnpr.healthbot import DeviceSchema
                ds = DeviceSchema(device_id='xyz', host='xx.xxx.xxx.xxx',
                      authentication={"password": {"password": "xxxxx", "username": "xxxxx"}})

                # we can also later assign values like this
                ds.description = "HbEZ testing"

                # This will add device in candidate DB
                hb.device.add(schema=ds)

                # Add device group
                print(hb.device_group.add(device_group_name="edge",
                description="All devices on the edge", devices=['demo']))

                # commit changes to master DB
                hb.commit()

                # get details of a given topic/rule
                pprint(hb.rule.get('linecard.ospf', 'check-ddos-statistics'))

        """
        self.server = server
        self.user = user
        self.password = password
        self._version = ""

        self.port = kwargs.get('port', 8080)

        if server is None or server == "":
            raise ValueError("You must provide 'server' of HealthBot")

        if user is None or user == "":
            raise ValueError("You must provide 'user' of HealthBot")

        if password is None or password == "":
            raise ValueError("You must provide 'password' of HealthBot")

        self._hbot_session = None
        self._user_token = None
        self.api_client = None
        self._auth = None
        self.connected = False
        self._token_expire_time = None

    def open(self):
        """
        Open session with HealthBot server. First sets user token (for healthbot
        3.0.0 and above) and check a top level URL for confirmation of API to be
        working.

        """
        # set_user_token returning False can be the case for older Healthbot
        if not self.set_user_token():
            try:
                # Call one dummy URL to check if login was successful
                # needed for <3.0 HealthBots
                req = self.hbot_session.get(self.url + '/device')
                # HTTP errors are not raised by default, this statement does that
                req.raise_for_status()
                self.connected = True
            except HTTPError as ex:
                logger.error("Check user credentials")
                raise ConnectAuthError(self, "Check user credentials")
            except Exception as ex:
                logger.error("Error: {}".format(ex))
                raise ex
            else:
                logger.debug(
                    "Connected to HealthBot Server({}) on port {}".format(
                        self.server, self.port))

        self._version = self.version
        self.urlfor = UrlFor(self)
        self.device = devices.Device(self)
        self.device_group = devices.DeviceGroup(self)
        self.network_group = devices.NetworkGroup(self)
        self.rule = rules.Rule(self)
        self.topic = rules.Topic(self)
        self.playbook = playbooks.Playbook(self)
        self.settings = settings.Settings(self)
        self.profile = profiles.Profile(self)
        self.charts = graph.HBCharts(self)

        config_bm = BaseModule(self, self.config_url)
        self.authorization = config_bm.authorization
        self.configuration = ConfigurationApi(config_bm.api_client)

        self.data_store = DataStoreApi(config_bm.api_client)
        self.services = ServicesApi(config_bm.api_client)
        self.default = DefaultApi(config_bm.api_client)
        self.instance_schedule = InstanceScheduleStateApi(config_bm.api_client)
        non_config_bm = BaseModule(self, self.url)
        self.license = LicenseApi(non_config_bm.api_client)
        self.data_source = DataSourceApi(non_config_bm.api_client)
        self.system = SystemApi(non_config_bm.api_client)
        self.debug = DebugApi(non_config_bm.api_client)
        return self

    login = open

    def set_user_token(self):
        """
        From HealthBot 3.0.0 APIs will be token based. This function helps in
        setting user based token. This token will be used in header of any
        REST API calls.

        """
        conf = Configuration()
        conf.host = self.url
        conf.verify_ssl = False
        self.api_client = ApiClient(configuration=conf)
        self._auth = AuthenticationApi(api_client=self.api_client)
        try:
            self._user_token = self._auth.user_login(
                credential={"userName": self.user, "password": self.password})
            self._token_expire_time = time.time() + \
                                      int(self._user_token.token_expires)
            self.hbot_session.headers.update({
              'x-iam-token': self._user_token.access_token})
            self.connected = True
        except ApiException as ex:
            logger.debug("Check if given HealthBot version support authorization key")
            # set user/password used by older healthbot version APIs
            self.hbot_session.auth = (self.user, self.password)
            return False
        except Exception as ex:
            logger.error("User Login Error: {}".format(ex))
            raise ex
        return True

    @property
    def tenant(self):
        raw_data = jwt.decode(self._user_token.access_token,
                              options={"verify_aud": False, "verify_signature": False, "verify_nbf": False})
        return raw_data['scope']['Name']

    @property
    def hbot_session(self):
        """
        Property provides requests module session object. Also help in updating
        Access token key when expires. Any call to hbot_session.apis should go
        through this property to keep a check on token key expiry.

        """
        if self._hbot_session is None:
            self._hbot_session = requests.Session()
            self._hbot_session.headers.update(
                {"Accept": "application/json", "Content-Type": "application/json"}
            )
            self._hbot_session.verify = False
        # this call should make sure to check for token expiry
        self.user_token
        return self._hbot_session

    @property
    def user_token(self):
        if self._token_expire_time and time.time() >= self._token_expire_time:
            logger.debug("Token expired, hence refreshing")
            obj = self._auth.refresh_token(token=Token(
                refresh_token=self._user_token.refresh_token))
            self._user_token.access_token = obj.access_token
            self._user_token.refresh_token = obj.refresh_token
            self._hbot_session.headers.update({
                    'x-iam-token': self._user_token.access_token})
            self._token_expire_time = time.time() + \
                                      int(self._user_token.token_expires)
        return self._user_token

    def logout(self):
        """
        Call user logout function to discard access tokens.

        """
        if self._user_token:
            refresh_token = RefreshToken(token=self._user_token.refresh_token)
            self._auth.user_logout(refresh_token=refresh_token)

    @property
    def tsdb(self):
        """
        Connection to the tsdb

        :return: InfluxDBClient
        """
        return database.Database(self)

    @tsdb.setter
    def tsdb(self, value):
        """ read-only property """
        raise RuntimeError("tsdb is read-only!")

    @property
    def config_url(self):
        """
        This function will give config URL

        """
        return self.url + "/config"

    @property
    def url(self):
        """ Initials of URL to be used for API call.
        :returns:
            str: Initials of URL to be used for API call.
        """
        url_initials = "https://" + self.server + ":" + str(self.port) + "/api/"
        return url_initials + "v2"

    @property
    def grafana_url(self):
        return "https://" + self.server + ":" + str(self.port) + "/grafana/api"

    @property
    def version(self):
        """ TO get the version of Healthbot Server

        :returns:
            str: API server version.
        """
        if self._version == "":
            system_details_url = "{api}/system-details".format(api=self.url)
            resp = self.api.get(system_details_url)
            if resp.status_code == 200:
                hb_version = resp.json().get('version', '')
                obj = re.search(r'HealthBot (\d\.\d\.\d)', hb_version)
                if obj:
                    self._version = obj.group(1)
                    # to refresh user token to use v2, as we started with v1
                    # this should be cleaned/deleted in future.
                    self.api_client.configuration.host = self.url
        return self._version

    @property
    def api(self):
        return self.hbot_session

    def commit(self):
        """
        Commit any candidate configuration

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import DeviceSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ds = DeviceSchema(device_id='xyz', host='xx.xxx.xxx.xxx',
                      authentication={"password": {"password": "xxxxx", "username": "xxxxx"}})

                # we can also later assign values like this
                ds.description = "HbEZ testing"

                # This will add device in candidate DB
                hb.device.add(schema=ds)

                # commit changes to master DB
                hb.commit()

        :raises: Any requests exception

        :returns: True when OK
        """
        response = self.hbot_session.post(
            "{api}/configuration".format(api=self.config_url))
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return response.ok

    def rollback(self):
        """
        Rollback any candidate configuration

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                # This will delete device in candidate DB
                hb.device.delete('xyz')

                # rollback candidate configuration
                hb.rollback()

        :raises: Any requests exception

        :returns: True when OK
        """
        response = self.hbot_session.delete(
            "{api}/configuration".format(api=self.url))
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return response.ok

    def upload_helper_file(self, filename):
        """
        Upload a "helper-file" to the server.  A helper-file, cab be
         YAML/.py/.rule/.playbook file.

        :param str filename: The name of the file to be uploaded.
        """

        # when using the 'files' option to POST, we must remove the content-type from the
        # headers since the requests library uses/fills this in according to
        # the file

        c_type = self.hbot_session.headers.pop('Content-Type')
        try:
            file_p = Path(os.path.abspath(filename))
            # upload rule/playbook file
            if filename.endswith('.rule'):
                url = self.urlfor.topics()
                files = {'topics': file_p.open('rb')}
            elif filename.endswith('.playbook'):
                url = self.urlfor.playbooks()
                files = {'playbooks': file_p.open('rb')}
            else:
                url = self.urlfor.helper_files(name=file_p.name)
                files = {'up_file': file_p.open('rb')}
            response = self.hbot_session.post(url=url, files=files)

            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
        finally:
            self.hbot_session.headers['Content-Type'] = c_type
        return True

    def _create_schema(self, response: requests.models.Response, schema):
        attribute_map = schema.attribute_map
        if not isinstance(response, dict):
            attributes = dict()
            if isinstance(response, Response):
                response = response.json()
                attribute_map_values = attribute_map.values()
                attribute_map_reversed = {v: k for k, v in attribute_map.items()}
                for key, value in response.items():
                    if key in attribute_map_values:
                        attributes[attribute_map_reversed[key]] = response.get(key)
            else:
                response = response.to_dict()
                for key, value in response.items():
                    if key in attribute_map:
                        attributes[key] = response.get(key)
            return schema(**attributes)
        else:
            attributes = dict()
            attribute_map_values = attribute_map.values()
            attribute_map_reversed = {v: k for k, v in attribute_map.items()}
            for key, value in response.items():
                if key in attribute_map_values:
                    attributes[attribute_map_reversed[key]] = response.get(key)
            return schema(**attributes)

    def _create_payload(self, schemaObj):
        """
        remove keys which got None as value

        :param payload: dict which needs clean up of None values
        :return: dict of payload without None values
        """
        try:
            payload = schemaObj.to_dict()
        except AttributeError:
            if isinstance(schemaObj, dict):
                return schemaObj
            else:
                raise
        # remove None values
        attribute_map = schemaObj.attribute_map
        attributes = dict()
        for key, value in payload.items():
            if value is not None:
                if key in attribute_map:
                    if isinstance(value, dict):
                        childSchema = getattr(schemaObj, key)
                        if isinstance(childSchema, dict):
                            # childSchema is not any schema, hence set it to
                            # payload
                            attributes[attribute_map[key]] = payload.get(key)
                        else:
                            attributes[attribute_map[key]
                                       ] = self._create_payload(childSchema)
                    elif isinstance(value, list) and filter(
                            lambda i: isinstance(i, dict), value):
                        childSchemas = getattr(schemaObj, key)
                        attributes[attribute_map[key]] = []
                        for childSchema in childSchemas:
                            if isinstance(childSchema, str):
                                child_val = childSchema
                            else:
                                child_val = self._create_payload(childSchema)
                            attributes[attribute_map[key]].append(child_val)
                    else:
                        attributes[attribute_map[key]] = payload.get(key)
        return attributes

    def health(self):
        """
        Returns health of network-groups and devices in device-groups
        `HealthSchema <jnpr.healthbot.swagger.models.html#healthschema>`_

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.health())

        :return: `HealthSchema <jnpr.healthbot.swagger.models.html#healthschema>`_
        """

        health_url = self.urlfor.health()
        resp = self.api.get(health_url)

        if resp.status_code == 404:
            return {}
        return self._create_schema(resp, HealthSchema)

    def close(self):
        self.hbot_session.close()
        self.connected = False

    def __repr__(self):
        return "HealthBot(%s)" % self.server
    # -----------------------------------------------------------------------
    # Context Manager
    # -----------------------------------------------------------------------

    def __enter__(self):
        return self.login()

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.logout()
        self.connected = False

    def __repr__(self):
        return "HealthBot(%s)" % self.server



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaSensor(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_if_missing': 'RuleSchemaDataifmissing',
        'path': 'str',
        'sensor_name': 'str',
        'where': 'list[RuleSchemaWhere]',
        'zero_suppression': 'list[object]'
    }

    attribute_map = {
        'data_if_missing': 'data-if-missing',
        'path': 'path',
        'sensor_name': 'sensor-name',
        'where': 'where',
        'zero_suppression': 'zero-suppression'
    }

    def __init__(self, data_if_missing=None, path=None, sensor_name=None, where=None, zero_suppression=None):  # noqa: E501
        """RuleSchemaSensor - a model defined in Swagger"""  # noqa: E501

        self._data_if_missing = None
        self._path = None
        self._sensor_name = None
        self._where = None
        self._zero_suppression = None
        self.discriminator = None

        if data_if_missing is not None:
            self.data_if_missing = data_if_missing
        self.path = path
        self.sensor_name = sensor_name
        if where is not None:
            self.where = where
        if zero_suppression is not None:
            self.zero_suppression = zero_suppression

    @property
    def data_if_missing(self):
        """Gets the data_if_missing of this RuleSchemaSensor.  # noqa: E501


        :return: The data_if_missing of this RuleSchemaSensor.  # noqa: E501
        :rtype: RuleSchemaDataifmissing
        """
        return self._data_if_missing

    @data_if_missing.setter
    def data_if_missing(self, data_if_missing):
        """Sets the data_if_missing of this RuleSchemaSensor.


        :param data_if_missing: The data_if_missing of this RuleSchemaSensor.  # noqa: E501
        :type: RuleSchemaDataifmissing
        """

        self._data_if_missing = data_if_missing

    @property
    def path(self):
        """Gets the path of this RuleSchemaSensor.  # noqa: E501

        Sensor path  # noqa: E501

        :return: The path of this RuleSchemaSensor.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this RuleSchemaSensor.

        Sensor path  # noqa: E501

        :param path: The path of this RuleSchemaSensor.  # noqa: E501
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501
        if path is not None and not re.search(r'^\\S+$', path):  # noqa: E501
            raise ValueError(r"Invalid value for `path`, must be a follow pattern or equal to `/^\\S+$/`")  # noqa: E501

        self._path = path

    @property
    def sensor_name(self):
        """Gets the sensor_name of this RuleSchemaSensor.  # noqa: E501

        Name of the sensor  # noqa: E501

        :return: The sensor_name of this RuleSchemaSensor.  # noqa: E501
        :rtype: str
        """
        return self._sensor_name

    @sensor_name.setter
    def sensor_name(self, sensor_name):
        """Sets the sensor_name of this RuleSchemaSensor.

        Name of the sensor  # noqa: E501

        :param sensor_name: The sensor_name of this RuleSchemaSensor.  # noqa: E501
        :type: str
        """
        if sensor_name is None:
            raise ValueError("Invalid value for `sensor_name`, must not be `None`")  # noqa: E501
        if sensor_name is not None and len(sensor_name) > 64:
            raise ValueError("Invalid value for `sensor_name`, length must be less than or equal to `64`")  # noqa: E501
        if sensor_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', sensor_name):  # noqa: E501
            raise ValueError(r"Invalid value for `sensor_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._sensor_name = sensor_name

    @property
    def where(self):
        """Gets the where of this RuleSchemaSensor.  # noqa: E501

        List of where clauses to filter ingest data  # noqa: E501

        :return: The where of this RuleSchemaSensor.  # noqa: E501
        :rtype: list[RuleSchemaWhere]
        """
        return self._where

    @where.setter
    def where(self, where):
        """Sets the where of this RuleSchemaSensor.

        List of where clauses to filter ingest data  # noqa: E501

        :param where: The where of this RuleSchemaSensor.  # noqa: E501
        :type: list[RuleSchemaWhere]
        """

        self._where = where

    @property
    def zero_suppression(self):
        """Gets the zero_suppression of this RuleSchemaSensor.  # noqa: E501

        Assign zero as default value for field in case of zero-suppression  # noqa: E501

        :return: The zero_suppression of this RuleSchemaSensor.  # noqa: E501
        :rtype: list[object]
        """
        return self._zero_suppression

    @zero_suppression.setter
    def zero_suppression(self, zero_suppression):
        """Sets the zero_suppression of this RuleSchemaSensor.

        Assign zero as default value for field in case of zero-suppression  # noqa: E501

        :param zero_suppression: The zero_suppression of this RuleSchemaSensor.  # noqa: E501
        :type: list[object]
        """

        self._zero_suppression = zero_suppression

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaSensor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaSensor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NetworkGroupSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'ingest_frequency': 'list[str]',
        'network_group_name': 'str',
        'publish': 'NetworkgroupSchemaPublish',
        'logging': 'NetworkgroupSchemaLogging',
        'reports': 'list[str]',
        'root_cause_analysis': 'DevicegroupSchemaRootcauseanalysis',
        'notification': 'NetworkgroupSchemaNotification',
        'playbooks': 'list[str]',
        'tagging_profile': 'list[str]',
        'scheduler': 'list[DevicegroupSchemaScheduler]',
        'variable': 'list[DevicegroupSchemaVariable]',
        'action_scheduler': 'DevicegroupSchemaActionscheduler'
    }

    attribute_map = {
        'description': 'description',
        'ingest_frequency': 'ingest-frequency',
        'network_group_name': 'network-group-name',
        'publish': 'publish',
        'logging': 'logging',
        'reports': 'reports',
        'root_cause_analysis': 'root-cause-analysis',
        'notification': 'notification',
        'playbooks': 'playbooks',
        'tagging_profile': 'tagging-profile',
        'scheduler': 'scheduler',
        'variable': 'variable',
        'action_scheduler': 'action-scheduler'
    }

    def __init__(self, description=None, ingest_frequency=None, network_group_name=None, publish=None, logging=None, reports=None, root_cause_analysis=None, notification=None, playbooks=None, tagging_profile=None, scheduler=None, variable=None, action_scheduler=None):  # noqa: E501
        """NetworkGroupSchema - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._ingest_frequency = None
        self._network_group_name = None
        self._publish = None
        self._logging = None
        self._reports = None
        self._root_cause_analysis = None
        self._notification = None
        self._playbooks = None
        self._tagging_profile = None
        self._scheduler = None
        self._variable = None
        self._action_scheduler = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if ingest_frequency is not None:
            self.ingest_frequency = ingest_frequency
        self.network_group_name = network_group_name
        if publish is not None:
            self.publish = publish
        if logging is not None:
            self.logging = logging
        if reports is not None:
            self.reports = reports
        if root_cause_analysis is not None:
            self.root_cause_analysis = root_cause_analysis
        if notification is not None:
            self.notification = notification
        if playbooks is not None:
            self.playbooks = playbooks
        if tagging_profile is not None:
            self.tagging_profile = tagging_profile
        if scheduler is not None:
            self.scheduler = scheduler
        if variable is not None:
            self.variable = variable
        if action_scheduler is not None:
            self.action_scheduler = action_scheduler

    @property
    def description(self):
        """Gets the description of this NetworkGroupSchema.  # noqa: E501

        Description about the network group  # noqa: E501

        :return: The description of this NetworkGroupSchema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this NetworkGroupSchema.

        Description about the network group  # noqa: E501

        :param description: The description of this NetworkGroupSchema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def ingest_frequency(self):
        """Gets the ingest_frequency of this NetworkGroupSchema.  # noqa: E501


        :return: The ingest_frequency of this NetworkGroupSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._ingest_frequency

    @ingest_frequency.setter
    def ingest_frequency(self, ingest_frequency):
        """Sets the ingest_frequency of this NetworkGroupSchema.


        :param ingest_frequency: The ingest_frequency of this NetworkGroupSchema.  # noqa: E501
        :type: list[str]
        """

        self._ingest_frequency = ingest_frequency

    @property
    def network_group_name(self):
        """Gets the network_group_name of this NetworkGroupSchema.  # noqa: E501

        Name of the network group. Should be of pattern [a-zA-Z][a-zA-Z0-9-]*  # noqa: E501

        :return: The network_group_name of this NetworkGroupSchema.  # noqa: E501
        :rtype: str
        """
        return self._network_group_name

    @network_group_name.setter
    def network_group_name(self, network_group_name):
        """Sets the network_group_name of this NetworkGroupSchema.

        Name of the network group. Should be of pattern [a-zA-Z][a-zA-Z0-9-]*  # noqa: E501

        :param network_group_name: The network_group_name of this NetworkGroupSchema.  # noqa: E501
        :type: str
        """
        if network_group_name is None:
            raise ValueError("Invalid value for `network_group_name`, must not be `None`")  # noqa: E501
        if network_group_name is not None and len(network_group_name) > 40:
            raise ValueError("Invalid value for `network_group_name`, length must be less than or equal to `40`")  # noqa: E501
        if network_group_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9-]*$', network_group_name):  # noqa: E501
            raise ValueError(r"Invalid value for `network_group_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9-]*$/`")  # noqa: E501

        self._network_group_name = network_group_name

    @property
    def publish(self):
        """Gets the publish of this NetworkGroupSchema.  # noqa: E501


        :return: The publish of this NetworkGroupSchema.  # noqa: E501
        :rtype: NetworkgroupSchemaPublish
        """
        return self._publish

    @publish.setter
    def publish(self, publish):
        """Sets the publish of this NetworkGroupSchema.


        :param publish: The publish of this NetworkGroupSchema.  # noqa: E501
        :type: NetworkgroupSchemaPublish
        """

        self._publish = publish

    @property
    def logging(self):
        """Gets the logging of this NetworkGroupSchema.  # noqa: E501


        :return: The logging of this NetworkGroupSchema.  # noqa: E501
        :rtype: NetworkgroupSchemaLogging
        """
        return self._logging

    @logging.setter
    def logging(self, logging):
        """Sets the logging of this NetworkGroupSchema.


        :param logging: The logging of this NetworkGroupSchema.  # noqa: E501
        :type: NetworkgroupSchemaLogging
        """

        self._logging = logging

    @property
    def reports(self):
        """Gets the reports of this NetworkGroupSchema.  # noqa: E501


        :return: The reports of this NetworkGroupSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._reports

    @reports.setter
    def reports(self, reports):
        """Sets the reports of this NetworkGroupSchema.


        :param reports: The reports of this NetworkGroupSchema.  # noqa: E501
        :type: list[str]
        """

        self._reports = reports

    @property
    def root_cause_analysis(self):
        """Gets the root_cause_analysis of this NetworkGroupSchema.  # noqa: E501


        :return: The root_cause_analysis of this NetworkGroupSchema.  # noqa: E501
        :rtype: DevicegroupSchemaRootcauseanalysis
        """
        return self._root_cause_analysis

    @root_cause_analysis.setter
    def root_cause_analysis(self, root_cause_analysis):
        """Sets the root_cause_analysis of this NetworkGroupSchema.


        :param root_cause_analysis: The root_cause_analysis of this NetworkGroupSchema.  # noqa: E501
        :type: DevicegroupSchemaRootcauseanalysis
        """

        self._root_cause_analysis = root_cause_analysis

    @property
    def notification(self):
        """Gets the notification of this NetworkGroupSchema.  # noqa: E501


        :return: The notification of this NetworkGroupSchema.  # noqa: E501
        :rtype: NetworkgroupSchemaNotification
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        """Sets the notification of this NetworkGroupSchema.


        :param notification: The notification of this NetworkGroupSchema.  # noqa: E501
        :type: NetworkgroupSchemaNotification
        """

        self._notification = notification

    @property
    def playbooks(self):
        """Gets the playbooks of this NetworkGroupSchema.  # noqa: E501


        :return: The playbooks of this NetworkGroupSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._playbooks

    @playbooks.setter
    def playbooks(self, playbooks):
        """Sets the playbooks of this NetworkGroupSchema.


        :param playbooks: The playbooks of this NetworkGroupSchema.  # noqa: E501
        :type: list[str]
        """

        self._playbooks = playbooks

    @property
    def tagging_profile(self):
        """Gets the tagging_profile of this NetworkGroupSchema.  # noqa: E501


        :return: The tagging_profile of this NetworkGroupSchema.  # noqa: E501
        :rtype: list[str]
        """
        return self._tagging_profile

    @tagging_profile.setter
    def tagging_profile(self, tagging_profile):
        """Sets the tagging_profile of this NetworkGroupSchema.


        :param tagging_profile: The tagging_profile of this NetworkGroupSchema.  # noqa: E501
        :type: list[str]
        """

        self._tagging_profile = tagging_profile

    @property
    def scheduler(self):
        """Gets the scheduler of this NetworkGroupSchema.  # noqa: E501

        List of schedulers associated with the playbook instances  # noqa: E501

        :return: The scheduler of this NetworkGroupSchema.  # noqa: E501
        :rtype: list[DevicegroupSchemaScheduler]
        """
        return self._scheduler

    @scheduler.setter
    def scheduler(self, scheduler):
        """Sets the scheduler of this NetworkGroupSchema.

        List of schedulers associated with the playbook instances  # noqa: E501

        :param scheduler: The scheduler of this NetworkGroupSchema.  # noqa: E501
        :type: list[DevicegroupSchemaScheduler]
        """

        self._scheduler = scheduler

    @property
    def variable(self):
        """Gets the variable of this NetworkGroupSchema.  # noqa: E501

        Playbook variable configuration  # noqa: E501

        :return: The variable of this NetworkGroupSchema.  # noqa: E501
        :rtype: list[DevicegroupSchemaVariable]
        """
        return self._variable

    @variable.setter
    def variable(self, variable):
        """Sets the variable of this NetworkGroupSchema.

        Playbook variable configuration  # noqa: E501

        :param variable: The variable of this NetworkGroupSchema.  # noqa: E501
        :type: list[DevicegroupSchemaVariable]
        """

        self._variable = variable

    @property
    def action_scheduler(self):
        """Gets the action_scheduler of this NetworkGroupSchema.  # noqa: E501


        :return: The action_scheduler of this NetworkGroupSchema.  # noqa: E501
        :rtype: DevicegroupSchemaActionscheduler
        """
        return self._action_scheduler

    @action_scheduler.setter
    def action_scheduler(self, action_scheduler):
        """Sets the action_scheduler of this NetworkGroupSchema.


        :param action_scheduler: The action_scheduler of this NetworkGroupSchema.  # noqa: E501
        :type: DevicegroupSchemaActionscheduler
        """

        self._action_scheduler = action_scheduler

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkGroupSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkGroupSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaggingprofileSchemaWhenExists(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field': 'str',
        'path': 'str',
        'in_memory': 'bool'
    }

    attribute_map = {
        'field': 'field',
        'path': 'path',
        'in_memory': 'in-memory'
    }

    def __init__(self, field=None, path=None, in_memory=None):  # noqa: E501
        """TaggingprofileSchemaWhenExists - a model defined in Swagger"""  # noqa: E501

        self._field = None
        self._path = None
        self._in_memory = None
        self.discriminator = None

        self.field = field
        if path is not None:
            self.path = path
        if in_memory is not None:
            self.in_memory = in_memory

    @property
    def field(self):
        """Gets the field of this TaggingprofileSchemaWhenExists.  # noqa: E501

        This is the string that we need to look for within path when in-memory is set to True, else this contains the field-name that we need to look for in TSDB  # noqa: E501

        :return: The field of this TaggingprofileSchemaWhenExists.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this TaggingprofileSchemaWhenExists.

        This is the string that we need to look for within path when in-memory is set to True, else this contains the field-name that we need to look for in TSDB  # noqa: E501

        :param field: The field of this TaggingprofileSchemaWhenExists.  # noqa: E501
        :type: str
        """
        if field is None:
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field

    @property
    def path(self):
        """Gets the path of this TaggingprofileSchemaWhenExists.  # noqa: E501

        Look for the field value in the given path, if it exist as key in dict or value in list if in-memory is set to true  # noqa: E501

        :return: The path of this TaggingprofileSchemaWhenExists.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this TaggingprofileSchemaWhenExists.

        Look for the field value in the given path, if it exist as key in dict or value in list if in-memory is set to true  # noqa: E501

        :param path: The path of this TaggingprofileSchemaWhenExists.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def in_memory(self):
        """Gets the in_memory of this TaggingprofileSchemaWhenExists.  # noqa: E501

        Look for field in internal cache path  # noqa: E501

        :return: The in_memory of this TaggingprofileSchemaWhenExists.  # noqa: E501
        :rtype: bool
        """
        return self._in_memory

    @in_memory.setter
    def in_memory(self, in_memory):
        """Sets the in_memory of this TaggingprofileSchemaWhenExists.

        Look for field in internal cache path  # noqa: E501

        :param in_memory: The in_memory of this TaggingprofileSchemaWhenExists.  # noqa: E501
        :type: bool
        """

        self._in_memory = in_memory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaggingprofileSchemaWhenExists, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaggingprofileSchemaWhenExists):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class OrganizationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_healthbot_organization_site_edge_edge_by_id(self, organization_name, site_name, edge_name, edge, **kwargs):  # noqa: E501
        """Create edge by ID  # noqa: E501

        Create operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_healthbot_organization_site_edge_edge_by_id(organization_name, site_name, edge_name, edge, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param EdgeSchema edge: edgebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, edge, **kwargs)  # noqa: E501
        else:
            (data) = self.create_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, edge, **kwargs)  # noqa: E501
            return data

    def create_healthbot_organization_site_edge_edge_by_id_with_http_info(self, organization_name, site_name, edge_name, edge, **kwargs):  # noqa: E501
        """Create edge by ID  # noqa: E501

        Create operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, edge, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param EdgeSchema edge: edgebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'edge_name', 'edge', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_healthbot_organization_site_edge_edge_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `create_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `create_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'edge_name' is set
        if ('edge_name' not in params or
                params['edge_name'] is None):
            raise ValueError("Missing the required parameter `edge_name` when calling `create_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'edge' is set
        if ('edge' not in params or
                params['edge'] is None):
            raise ValueError("Missing the required parameter `edge` when calling `create_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501
        if 'edge_name' in params:
            path_params['edge_name'] = params['edge_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'edge' in params:
            body_params = params['edge']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/edge/{edge_name}/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_healthbot_organization_site_site_by_id(self, organization_name, site_name, site, **kwargs):  # noqa: E501
        """Create site by ID  # noqa: E501

        Create operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_healthbot_organization_site_site_by_id(organization_name, site_name, site, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param SiteSchema site: sitebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, site, **kwargs)  # noqa: E501
        else:
            (data) = self.create_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, site, **kwargs)  # noqa: E501
            return data

    def create_healthbot_organization_site_site_by_id_with_http_info(self, organization_name, site_name, site, **kwargs):  # noqa: E501
        """Create site by ID  # noqa: E501

        Create operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, site, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param SiteSchema site: sitebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'site', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_healthbot_organization_site_site_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `create_healthbot_organization_site_site_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `create_healthbot_organization_site_site_by_id`")  # noqa: E501
        # verify the required parameter 'site' is set
        if ('site' not in params or
                params['site'] is None):
            raise ValueError("Missing the required parameter `site` when calling `create_healthbot_organization_site_site_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'site' in params:
            body_params = params['site']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_healthbot_organization_site_edge_edge_by_id(self, organization_name, site_name, edge_name, **kwargs):  # noqa: E501
        """Delete edge by ID  # noqa: E501

        Delete operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_healthbot_organization_site_edge_edge_by_id(organization_name, site_name, edge_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, **kwargs)  # noqa: E501
            return data

    def delete_healthbot_organization_site_edge_edge_by_id_with_http_info(self, organization_name, site_name, edge_name, **kwargs):  # noqa: E501
        """Delete edge by ID  # noqa: E501

        Delete operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'edge_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_healthbot_organization_site_edge_edge_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `delete_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `delete_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'edge_name' is set
        if ('edge_name' not in params or
                params['edge_name'] is None):
            raise ValueError("Missing the required parameter `edge_name` when calling `delete_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501
        if 'edge_name' in params:
            path_params['edge_name'] = params['edge_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/edge/{edge_name}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_healthbot_organization_site_site_by_id(self, organization_name, site_name, **kwargs):  # noqa: E501
        """Delete site by ID  # noqa: E501

        Delete operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_healthbot_organization_site_site_by_id(organization_name, site_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, **kwargs)  # noqa: E501
            return data

    def delete_healthbot_organization_site_site_by_id_with_http_info(self, organization_name, site_name, **kwargs):  # noqa: E501
        """Delete site by ID  # noqa: E501

        Delete operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_healthbot_organization_site_site_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `delete_healthbot_organization_site_site_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `delete_healthbot_organization_site_site_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_healthbot_organization_site_edge_edge_by_id(self, organization_name, site_name, edge_name, **kwargs):  # noqa: E501
        """Retrieve edge by ID  # noqa: E501

        Retrieve operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_healthbot_organization_site_edge_edge_by_id(organization_name, site_name, edge_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param str x_iam_token: authentication header object
        :param bool working: true queries undeployed configuration
        :return: EdgeSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, **kwargs)  # noqa: E501
            return data

    def retrieve_healthbot_organization_site_edge_edge_by_id_with_http_info(self, organization_name, site_name, edge_name, **kwargs):  # noqa: E501
        """Retrieve edge by ID  # noqa: E501

        Retrieve operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param str x_iam_token: authentication header object
        :param bool working: true queries undeployed configuration
        :return: EdgeSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'edge_name', 'x_iam_token', 'working']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_healthbot_organization_site_edge_edge_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `retrieve_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `retrieve_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'edge_name' is set
        if ('edge_name' not in params or
                params['edge_name'] is None):
            raise ValueError("Missing the required parameter `edge_name` when calling `retrieve_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501
        if 'edge_name' in params:
            path_params['edge_name'] = params['edge_name']  # noqa: E501

        query_params = []
        if 'working' in params:
            query_params.append(('working', params['working']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/edge/{edge_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EdgeSchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_healthbot_organization_site_site_by_id(self, organization_name, site_name, **kwargs):  # noqa: E501
        """Retrieve site by ID  # noqa: E501

        Retrieve operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_healthbot_organization_site_site_by_id(organization_name, site_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str x_iam_token: authentication header object
        :param bool working: true queries undeployed configuration
        :return: SiteSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, **kwargs)  # noqa: E501
            return data

    def retrieve_healthbot_organization_site_site_by_id_with_http_info(self, organization_name, site_name, **kwargs):  # noqa: E501
        """Retrieve site by ID  # noqa: E501

        Retrieve operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str x_iam_token: authentication header object
        :param bool working: true queries undeployed configuration
        :return: SiteSchema
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'x_iam_token', 'working']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_healthbot_organization_site_site_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `retrieve_healthbot_organization_site_site_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `retrieve_healthbot_organization_site_site_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501

        query_params = []
        if 'working' in params:
            query_params.append(('working', params['working']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SiteSchema',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_healthbot_organization_site_edge_edge_by_id(self, organization_name, site_name, edge_name, edge, **kwargs):  # noqa: E501
        """Update edge by ID  # noqa: E501

        Update operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_healthbot_organization_site_edge_edge_by_id(organization_name, site_name, edge_name, edge, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param EdgeSchema edge: edgebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, edge, **kwargs)  # noqa: E501
        else:
            (data) = self.update_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, edge, **kwargs)  # noqa: E501
            return data

    def update_healthbot_organization_site_edge_edge_by_id_with_http_info(self, organization_name, site_name, edge_name, edge, **kwargs):  # noqa: E501
        """Update edge by ID  # noqa: E501

        Update operation of resource: edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_healthbot_organization_site_edge_edge_by_id_with_http_info(organization_name, site_name, edge_name, edge, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param str edge_name: ID of edge-name (required)
        :param EdgeSchema edge: edgebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'edge_name', 'edge', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_healthbot_organization_site_edge_edge_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `update_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `update_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'edge_name' is set
        if ('edge_name' not in params or
                params['edge_name'] is None):
            raise ValueError("Missing the required parameter `edge_name` when calling `update_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501
        # verify the required parameter 'edge' is set
        if ('edge' not in params or
                params['edge'] is None):
            raise ValueError("Missing the required parameter `edge` when calling `update_healthbot_organization_site_edge_edge_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501
        if 'edge_name' in params:
            path_params['edge_name'] = params['edge_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'edge' in params:
            body_params = params['edge']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/edge/{edge_name}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_healthbot_organization_site_site_by_id(self, organization_name, site_name, site, **kwargs):  # noqa: E501
        """Update site by ID  # noqa: E501

        Update operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_healthbot_organization_site_site_by_id(organization_name, site_name, site, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param SiteSchema site: sitebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, site, **kwargs)  # noqa: E501
        else:
            (data) = self.update_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, site, **kwargs)  # noqa: E501
            return data

    def update_healthbot_organization_site_site_by_id_with_http_info(self, organization_name, site_name, site, **kwargs):  # noqa: E501
        """Update site by ID  # noqa: E501

        Update operation of resource: site  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_healthbot_organization_site_site_by_id_with_http_info(organization_name, site_name, site, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str organization_name: ID of organization-name (required)
        :param str site_name: ID of site-name (required)
        :param SiteSchema site: sitebody object (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['organization_name', 'site_name', 'site', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_healthbot_organization_site_site_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'organization_name' is set
        if ('organization_name' not in params or
                params['organization_name'] is None):
            raise ValueError("Missing the required parameter `organization_name` when calling `update_healthbot_organization_site_site_by_id`")  # noqa: E501
        # verify the required parameter 'site_name' is set
        if ('site_name' not in params or
                params['site_name'] is None):
            raise ValueError("Missing the required parameter `site_name` when calling `update_healthbot_organization_site_site_by_id`")  # noqa: E501
        # verify the required parameter 'site' is set
        if ('site' not in params or
                params['site'] is None):
            raise ValueError("Missing the required parameter `site` when calling `update_healthbot_organization_site_site_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'organization_name' in params:
            path_params['organization_name'] = params['organization_name']  # noqa: E501
        if 'site_name' in params:
            path_params['site_name'] = params['site_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'site' in params:
            body_params = params['site']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/organization/{organization_name}/site/{site_name}/', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicegroupSchemaRootcauseanalysis(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'no_rca': 'list[object]',
        'dynamic_resources': 'list[str]',
        'exclude_resources': 'list[str]'
    }

    attribute_map = {
        'no_rca': 'no-rca',
        'dynamic_resources': 'dynamic-resources',
        'exclude_resources': 'exclude-resources'
    }

    def __init__(self, no_rca=None, dynamic_resources=None, exclude_resources=None):  # noqa: E501
        """DevicegroupSchemaRootcauseanalysis - a model defined in Swagger"""  # noqa: E501

        self._no_rca = None
        self._dynamic_resources = None
        self._exclude_resources = None
        self.discriminator = None

        if no_rca is not None:
            self.no_rca = no_rca
        if dynamic_resources is not None:
            self.dynamic_resources = dynamic_resources
        if exclude_resources is not None:
            self.exclude_resources = exclude_resources

    @property
    def no_rca(self):
        """Gets the no_rca of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501

        Disable Root Cause analysis  # noqa: E501

        :return: The no_rca of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501
        :rtype: list[object]
        """
        return self._no_rca

    @no_rca.setter
    def no_rca(self, no_rca):
        """Sets the no_rca of this DevicegroupSchemaRootcauseanalysis.

        Disable Root Cause analysis  # noqa: E501

        :param no_rca: The no_rca of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501
        :type: list[object]
        """

        self._no_rca = no_rca

    @property
    def dynamic_resources(self):
        """Gets the dynamic_resources of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501


        :return: The dynamic_resources of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501
        :rtype: list[str]
        """
        return self._dynamic_resources

    @dynamic_resources.setter
    def dynamic_resources(self, dynamic_resources):
        """Sets the dynamic_resources of this DevicegroupSchemaRootcauseanalysis.


        :param dynamic_resources: The dynamic_resources of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501
        :type: list[str]
        """

        self._dynamic_resources = dynamic_resources

    @property
    def exclude_resources(self):
        """Gets the exclude_resources of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501


        :return: The exclude_resources of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501
        :rtype: list[str]
        """
        return self._exclude_resources

    @exclude_resources.setter
    def exclude_resources(self, exclude_resources):
        """Sets the exclude_resources of this DevicegroupSchemaRootcauseanalysis.


        :param exclude_resources: The exclude_resources of this DevicegroupSchemaRootcauseanalysis.  # noqa: E501
        :type: list[str]
        """

        self._exclude_resources = exclude_resources

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicegroupSchemaRootcauseanalysis, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicegroupSchemaRootcauseanalysis):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



__author__ = "Nitin Kumar"
__author_email__ = "nitinkr@juniper.net"
__licence__ = "Apache 2.0"

from setuptools import setup, find_packages

import versioneer


def requirements(filename='requirements.txt'):
    return open(filename.strip()).readlines()


with open("README.md", "r") as fh:
    long_description = fh.read()


install_requires = requirements()

setup(
    name='hbez',
    version=versioneer.get_version(),
    description='Healthbot Python Client',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=__author__,
    package_dir={'': 'lib'},
    packages=find_packages('lib'),
    install_requires=install_requires,
    include_package_data=True,
    license=__licence__,
    keywords=['Juniper HealthBot'],
    python_requires='>=3.4',
    classifiers=[
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: System :: Networking',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)



# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 3.1.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Groups(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'group_name': 'str',
        'group_description': 'str',
        'roles': 'AssociatedRoleSchema',
        'users': 'AssociatedUserSchema'
    }

    attribute_map = {
        'group_name': 'groupName',
        'group_description': 'groupDescription',
        'roles': 'roles',
        'users': 'users'
    }

    def __init__(self, group_name=None, group_description=None, roles=None, users=None):  # noqa: E501
        """Groups - a model defined in Swagger"""  # noqa: E501

        self._group_name = None
        self._group_description = None
        self._roles = None
        self._users = None
        self.discriminator = None

        if group_name is not None:
            self.group_name = group_name
        if group_description is not None:
            self.group_description = group_description
        if roles is not None:
            self.roles = roles
        if users is not None:
            self.users = users

    @property
    def group_name(self):
        """Gets the group_name of this Groups.  # noqa: E501

        Name of the group  # noqa: E501

        :return: The group_name of this Groups.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this Groups.

        Name of the group  # noqa: E501

        :param group_name: The group_name of this Groups.  # noqa: E501
        :type: str
        """

        self._group_name = group_name

    @property
    def group_description(self):
        """Gets the group_description of this Groups.  # noqa: E501

        Details of the group  # noqa: E501

        :return: The group_description of this Groups.  # noqa: E501
        :rtype: str
        """
        return self._group_description

    @group_description.setter
    def group_description(self, group_description):
        """Sets the group_description of this Groups.

        Details of the group  # noqa: E501

        :param group_description: The group_description of this Groups.  # noqa: E501
        :type: str
        """

        self._group_description = group_description

    @property
    def roles(self):
        """Gets the roles of this Groups.  # noqa: E501


        :return: The roles of this Groups.  # noqa: E501
        :rtype: AssociatedRoleSchema
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Groups.


        :param roles: The roles of this Groups.  # noqa: E501
        :type: AssociatedRoleSchema
        """

        self._roles = roles

    @property
    def users(self):
        """Gets the users of this Groups.  # noqa: E501


        :return: The users of this Groups.  # noqa: E501
        :rtype: AssociatedUserSchema
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this Groups.


        :param users: The users of this Groups.  # noqa: E501
        :type: AssociatedUserSchema
        """

        self._users = users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Groups, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Groups):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaggingprofileSchemaWhenMatcheswithscheduler(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'scheduler': 'str',
        'time': 'str',
        'in_memory': 'bool'
    }

    attribute_map = {
        'scheduler': 'scheduler',
        'time': 'time',
        'in_memory': 'in-memory'
    }

    def __init__(self, scheduler=None, time=None, in_memory=None):  # noqa: E501
        """TaggingprofileSchemaWhenMatcheswithscheduler - a model defined in Swagger"""  # noqa: E501

        self._scheduler = None
        self._time = None
        self._in_memory = None
        self.discriminator = None

        self.scheduler = scheduler
        if time is not None:
            self.time = time
        if in_memory is not None:
            self.in_memory = in_memory

    @property
    def scheduler(self):
        """Gets the scheduler of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501

        Name of the scheduler defined within system/scheduler hierarchy  # noqa: E501

        :return: The scheduler of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501
        :rtype: str
        """
        return self._scheduler

    @scheduler.setter
    def scheduler(self, scheduler):
        """Sets the scheduler of this TaggingprofileSchemaWhenMatcheswithscheduler.

        Name of the scheduler defined within system/scheduler hierarchy  # noqa: E501

        :param scheduler: The scheduler of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501
        :type: str
        """
        if scheduler is None:
            raise ValueError("Invalid value for `scheduler`, must not be `None`")  # noqa: E501

        self._scheduler = scheduler

    @property
    def time(self):
        """Gets the time of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501

        Field holding time in UNIX time format. Optional default is point time  # noqa: E501

        :return: The time of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this TaggingprofileSchemaWhenMatcheswithscheduler.

        Field holding time in UNIX time format. Optional default is point time  # noqa: E501

        :param time: The time of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501
        :type: str
        """
        if time is not None and not re.search(r'^[$][a-z][a-zA-Z0-9_-]*$', time):  # noqa: E501
            raise ValueError(r"Invalid value for `time`, must be a follow pattern or equal to `/^[$][a-z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._time = time

    @property
    def in_memory(self):
        """Gets the in_memory of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501

        Look for time in internal cache  # noqa: E501

        :return: The in_memory of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501
        :rtype: bool
        """
        return self._in_memory

    @in_memory.setter
    def in_memory(self, in_memory):
        """Sets the in_memory of this TaggingprofileSchemaWhenMatcheswithscheduler.

        Look for time in internal cache  # noqa: E501

        :param in_memory: The in_memory of this TaggingprofileSchemaWhenMatcheswithscheduler.  # noqa: E501
        :type: bool
        """

        self._in_memory = in_memory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaggingprofileSchemaWhenMatcheswithscheduler, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaggingprofileSchemaWhenMatcheswithscheduler):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ProfilesSchemaProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'security': 'ProfileSchemaSecurity',
        'data_summarization': 'ProfileSchemaDatasummarization',
        'rollup_summarization': 'ProfileSchemaRollupsummarization'
    }

    attribute_map = {
        'security': 'security',
        'data_summarization': 'data-summarization',
        'rollup_summarization': 'rollup-summarization'
    }

    def __init__(self, security=None, data_summarization=None, rollup_summarization=None):  # noqa: E501
        """ProfilesSchemaProfile - a model defined in Swagger"""  # noqa: E501

        self._security = None
        self._data_summarization = None
        self._rollup_summarization = None
        self.discriminator = None

        if security is not None:
            self.security = security
        if data_summarization is not None:
            self.data_summarization = data_summarization
        if rollup_summarization is not None:
            self.rollup_summarization = rollup_summarization

    @property
    def security(self):
        """Gets the security of this ProfilesSchemaProfile.  # noqa: E501


        :return: The security of this ProfilesSchemaProfile.  # noqa: E501
        :rtype: ProfileSchemaSecurity
        """
        return self._security

    @security.setter
    def security(self, security):
        """Sets the security of this ProfilesSchemaProfile.


        :param security: The security of this ProfilesSchemaProfile.  # noqa: E501
        :type: ProfileSchemaSecurity
        """

        self._security = security

    @property
    def data_summarization(self):
        """Gets the data_summarization of this ProfilesSchemaProfile.  # noqa: E501


        :return: The data_summarization of this ProfilesSchemaProfile.  # noqa: E501
        :rtype: ProfileSchemaDatasummarization
        """
        return self._data_summarization

    @data_summarization.setter
    def data_summarization(self, data_summarization):
        """Sets the data_summarization of this ProfilesSchemaProfile.


        :param data_summarization: The data_summarization of this ProfilesSchemaProfile.  # noqa: E501
        :type: ProfileSchemaDatasummarization
        """

        self._data_summarization = data_summarization

    @property
    def rollup_summarization(self):
        """Gets the rollup_summarization of this ProfilesSchemaProfile.  # noqa: E501


        :return: The rollup_summarization of this ProfilesSchemaProfile.  # noqa: E501
        :rtype: ProfileSchemaRollupsummarization
        """
        return self._rollup_summarization

    @rollup_summarization.setter
    def rollup_summarization(self, rollup_summarization):
        """Sets the rollup_summarization of this ProfilesSchemaProfile.


        :param rollup_summarization: The rollup_summarization of this ProfilesSchemaProfile.  # noqa: E501
        :type: ProfileSchemaRollupsummarization
        """

        self._rollup_summarization = rollup_summarization

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfilesSchemaProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfilesSchemaProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from jnpr.healthbot.swagger.models.table_schema import TableSchema
from influxdb import InfluxDBClient
import logging
logger = logging.getLogger(__file__)


class Database(InfluxDBClient):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance

        Example:
        ::
            hb.tsdb.query("show databases")
            hb.tsdb.query('select * from "protocol-eventd-host/check-host-traffic/packet-loss" limit 10',
                              database='Core:vmx')
        """
        self.hbot = hbot
        self.url = hbot.url
        InfluxDBClient.__init__(self, hbot.server, 8086)

    @property
    def api(self):
        return self.hbot.hbot_session

    def get_table(self):
        """
        Get list of tables

        :return: list of `TableSchema <jnpr_healthbot_swagger/TableSchema.html>`_
        """
        get_tabel_url = self.hbot.urlfor.table()
        response = self.api.get(get_tabel_url)

        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return self.hbot._create_schema(response, TableSchema)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SflowSchemaSflow(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'counter_record': 'list[SflowSchemaSflowCounterrecord]',
        'flow_record': 'list[SflowSchemaSflowCounterrecord]',
        'protocol': 'list[SflowSchemaSflowProtocol]',
        'sample': 'list[SflowSchemaSflowSample]'
    }

    attribute_map = {
        'counter_record': 'counter-record',
        'flow_record': 'flow-record',
        'protocol': 'protocol',
        'sample': 'sample'
    }

    def __init__(self, counter_record=None, flow_record=None, protocol=None, sample=None):  # noqa: E501
        """SflowSchemaSflow - a model defined in Swagger"""  # noqa: E501

        self._counter_record = None
        self._flow_record = None
        self._protocol = None
        self._sample = None
        self.discriminator = None

        if counter_record is not None:
            self.counter_record = counter_record
        if flow_record is not None:
            self.flow_record = flow_record
        if protocol is not None:
            self.protocol = protocol
        if sample is not None:
            self.sample = sample

    @property
    def counter_record(self):
        """Gets the counter_record of this SflowSchemaSflow.  # noqa: E501

        Counter record formats  # noqa: E501

        :return: The counter_record of this SflowSchemaSflow.  # noqa: E501
        :rtype: list[SflowSchemaSflowCounterrecord]
        """
        return self._counter_record

    @counter_record.setter
    def counter_record(self, counter_record):
        """Sets the counter_record of this SflowSchemaSflow.

        Counter record formats  # noqa: E501

        :param counter_record: The counter_record of this SflowSchemaSflow.  # noqa: E501
        :type: list[SflowSchemaSflowCounterrecord]
        """

        self._counter_record = counter_record

    @property
    def flow_record(self):
        """Gets the flow_record of this SflowSchemaSflow.  # noqa: E501

        Flow record formats  # noqa: E501

        :return: The flow_record of this SflowSchemaSflow.  # noqa: E501
        :rtype: list[SflowSchemaSflowCounterrecord]
        """
        return self._flow_record

    @flow_record.setter
    def flow_record(self, flow_record):
        """Sets the flow_record of this SflowSchemaSflow.

        Flow record formats  # noqa: E501

        :param flow_record: The flow_record of this SflowSchemaSflow.  # noqa: E501
        :type: list[SflowSchemaSflowCounterrecord]
        """

        self._flow_record = flow_record

    @property
    def protocol(self):
        """Gets the protocol of this SflowSchemaSflow.  # noqa: E501

        Decoding schema for protocols found in sflow  # noqa: E501

        :return: The protocol of this SflowSchemaSflow.  # noqa: E501
        :rtype: list[SflowSchemaSflowProtocol]
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this SflowSchemaSflow.

        Decoding schema for protocols found in sflow  # noqa: E501

        :param protocol: The protocol of this SflowSchemaSflow.  # noqa: E501
        :type: list[SflowSchemaSflowProtocol]
        """

        self._protocol = protocol

    @property
    def sample(self):
        """Gets the sample of this SflowSchemaSflow.  # noqa: E501

        Sample types and their header fields  # noqa: E501

        :return: The sample of this SflowSchemaSflow.  # noqa: E501
        :rtype: list[SflowSchemaSflowSample]
        """
        return self._sample

    @sample.setter
    def sample(self, sample):
        """Sets the sample of this SflowSchemaSflow.

        Sample types and their header fields  # noqa: E501

        :param sample: The sample of this SflowSchemaSflow.  # noqa: E501
        :type: list[SflowSchemaSflowSample]
        """

        self._sample = sample

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SflowSchemaSflow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SflowSchemaSflow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaRulepropertiesSupporteddevicesJuniperReleases(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'release_name': 'str',
        'release_support': 'str',
        'sensors': 'list[str]'
    }

    attribute_map = {
        'release_name': 'release-name',
        'release_support': 'release-support',
        'sensors': 'sensors'
    }

    def __init__(self, release_name=None, release_support=None, sensors=None):  # noqa: E501
        """RuleSchemaRulepropertiesSupporteddevicesJuniperReleases - a model defined in Swagger"""  # noqa: E501

        self._release_name = None
        self._release_support = None
        self._sensors = None
        self.discriminator = None

        self.release_name = release_name
        if release_support is not None:
            self.release_support = release_support
        if sensors is not None:
            self.sensors = sensors

    @property
    def release_name(self):
        """Gets the release_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501

        Release name, Should be of pattern (\\d){1,2}[.](\\d){1}([\\w\\-_\\.]*)  # noqa: E501

        :return: The release_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501
        :rtype: str
        """
        return self._release_name

    @release_name.setter
    def release_name(self, release_name):
        """Sets the release_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.

        Release name, Should be of pattern (\\d){1,2}[.](\\d){1}([\\w\\-_\\.]*)  # noqa: E501

        :param release_name: The release_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501
        :type: str
        """
        if release_name is None:
            raise ValueError("Invalid value for `release_name`, must not be `None`")  # noqa: E501
        if release_name is not None and not re.search(r'^(\\d){1,2}[.](\\d){1}([\\w\\-_\\.]*)$', release_name):  # noqa: E501
            raise ValueError(r"Invalid value for `release_name`, must be a follow pattern or equal to `/^(\\d){1,2}[.](\\d){1}([\\w\\-_\\.]*)$/`")  # noqa: E501

        self._release_name = release_name

    @property
    def release_support(self):
        """Gets the release_support of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501

        Specifies the min/max support for this release  # noqa: E501

        :return: The release_support of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501
        :rtype: str
        """
        return self._release_support

    @release_support.setter
    def release_support(self, release_support):
        """Sets the release_support of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.

        Specifies the min/max support for this release  # noqa: E501

        :param release_support: The release_support of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501
        :type: str
        """
        allowed_values = ["max-supported-release", "only-on-this-release", "min-supported-release"]  # noqa: E501
        if release_support not in allowed_values:
            raise ValueError(
                "Invalid value for `release_support` ({0}), must be one of {1}"  # noqa: E501
                .format(release_support, allowed_values)
            )

        self._release_support = release_support

    @property
    def sensors(self):
        """Gets the sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501


        :return: The sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501
        :rtype: list[str]
        """
        return self._sensors

    @sensors.setter
    def sensors(self, sensors):
        """Sets the sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.


        :param sensors: The sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperReleases.  # noqa: E501
        :type: list[str]
        """

        self._sensors = sensors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaRulepropertiesSupporteddevicesJuniperReleases, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaRulepropertiesSupporteddevicesJuniperReleases):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HbGraphs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'graph_name': 'str',
        'graph_description': 'str',
        'graph_type': 'str',
        'time_range': 'str',
        'query': 'HbGraphsQuery',
        'y_label': 'str',
        'y_max': 'str',
        'y_min': 'str',
        'unit_type': 'str',
        'decimals': 'str'
    }

    attribute_map = {
        'graph_name': 'graph_name',
        'graph_description': 'graph_description',
        'graph_type': 'graph_type',
        'time_range': 'time_range',
        'query': 'query',
        'y_label': 'y_label',
        'y_max': 'y_max',
        'y_min': 'y_min',
        'unit_type': 'unit_type',
        'decimals': 'decimals'
    }

    def __init__(self, graph_name=None, graph_description=None, graph_type=None, time_range=None, query=None, y_label=None, y_max=None, y_min=None, unit_type=None, decimals=None):  # noqa: E501
        """HbGraphs - a model defined in Swagger"""  # noqa: E501

        self._graph_name = None
        self._graph_description = None
        self._graph_type = None
        self._time_range = None
        self._query = None
        self._y_label = None
        self._y_max = None
        self._y_min = None
        self._unit_type = None
        self._decimals = None
        self.discriminator = None

        if graph_name is not None:
            self.graph_name = graph_name
        if graph_description is not None:
            self.graph_description = graph_description
        if graph_type is not None:
            self.graph_type = graph_type
        if time_range is not None:
            self.time_range = time_range
        if query is not None:
            self.query = query
        if y_label is not None:
            self.y_label = y_label
        if y_max is not None:
            self.y_max = y_max
        if y_min is not None:
            self.y_min = y_min
        if unit_type is not None:
            self.unit_type = unit_type
        if decimals is not None:
            self.decimals = decimals

    @property
    def graph_name(self):
        """Gets the graph_name of this HbGraphs.  # noqa: E501

        Graph name  # noqa: E501

        :return: The graph_name of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._graph_name

    @graph_name.setter
    def graph_name(self, graph_name):
        """Sets the graph_name of this HbGraphs.

        Graph name  # noqa: E501

        :param graph_name: The graph_name of this HbGraphs.  # noqa: E501
        :type: str
        """

        self._graph_name = graph_name

    @property
    def graph_description(self):
        """Gets the graph_description of this HbGraphs.  # noqa: E501

        Graph description  # noqa: E501

        :return: The graph_description of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._graph_description

    @graph_description.setter
    def graph_description(self, graph_description):
        """Sets the graph_description of this HbGraphs.

        Graph description  # noqa: E501

        :param graph_description: The graph_description of this HbGraphs.  # noqa: E501
        :type: str
        """

        self._graph_description = graph_description

    @property
    def graph_type(self):
        """Gets the graph_type of this HbGraphs.  # noqa: E501

        Graph type: Time Series or Histogram or Heatmap  # noqa: E501

        :return: The graph_type of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._graph_type

    @graph_type.setter
    def graph_type(self, graph_type):
        """Sets the graph_type of this HbGraphs.

        Graph type: Time Series or Histogram or Heatmap  # noqa: E501

        :param graph_type: The graph_type of this HbGraphs.  # noqa: E501
        :type: str
        """
        allowed_values = ["Time Series", "Histogram", "Heatmap"]  # noqa: E501
        if graph_type not in allowed_values:
            raise ValueError(
                "Invalid value for `graph_type` ({0}), must be one of {1}"  # noqa: E501
                .format(graph_type, allowed_values)
            )

        self._graph_type = graph_type

    @property
    def time_range(self):
        """Gets the time_range of this HbGraphs.  # noqa: E501

        Time range for the graph  # noqa: E501

        :return: The time_range of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this HbGraphs.

        Time range for the graph  # noqa: E501

        :param time_range: The time_range of this HbGraphs.  # noqa: E501
        :type: str
        """
        allowed_values = ["1h", "3h", "6h", "12h", "1d", "2d", "3d", "4d", "5d", "6d", "7d"]  # noqa: E501
        if time_range not in allowed_values:
            raise ValueError(
                "Invalid value for `time_range` ({0}), must be one of {1}"  # noqa: E501
                .format(time_range, allowed_values)
            )

        self._time_range = time_range

    @property
    def query(self):
        """Gets the query of this HbGraphs.  # noqa: E501


        :return: The query of this HbGraphs.  # noqa: E501
        :rtype: HbGraphsQuery
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this HbGraphs.


        :param query: The query of this HbGraphs.  # noqa: E501
        :type: HbGraphsQuery
        """

        self._query = query

    @property
    def y_label(self):
        """Gets the y_label of this HbGraphs.  # noqa: E501

        Y Label value in visualization  # noqa: E501

        :return: The y_label of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._y_label

    @y_label.setter
    def y_label(self, y_label):
        """Sets the y_label of this HbGraphs.

        Y Label value in visualization  # noqa: E501

        :param y_label: The y_label of this HbGraphs.  # noqa: E501
        :type: str
        """

        self._y_label = y_label

    @property
    def y_max(self):
        """Gets the y_max of this HbGraphs.  # noqa: E501

        Y max value in visualization  # noqa: E501

        :return: The y_max of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._y_max

    @y_max.setter
    def y_max(self, y_max):
        """Sets the y_max of this HbGraphs.

        Y max value in visualization  # noqa: E501

        :param y_max: The y_max of this HbGraphs.  # noqa: E501
        :type: str
        """

        self._y_max = y_max

    @property
    def y_min(self):
        """Gets the y_min of this HbGraphs.  # noqa: E501

        Y min value in visualization  # noqa: E501

        :return: The y_min of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._y_min

    @y_min.setter
    def y_min(self, y_min):
        """Sets the y_min of this HbGraphs.

        Y min value in visualization  # noqa: E501

        :param y_min: The y_min of this HbGraphs.  # noqa: E501
        :type: str
        """

        self._y_min = y_min

    @property
    def unit_type(self):
        """Gets the unit_type of this HbGraphs.  # noqa: E501

        unit type value in visualization  # noqa: E501

        :return: The unit_type of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._unit_type

    @unit_type.setter
    def unit_type(self, unit_type):
        """Sets the unit_type of this HbGraphs.

        unit type value in visualization  # noqa: E501

        :param unit_type: The unit_type of this HbGraphs.  # noqa: E501
        :type: str
        """
        allowed_values = ["Short", "Percentage(0-100)", "Bits", "Bytes", "Kilobytes", "Megabytes", "Gigabytes", "Parts per million(ppm)", "Parts per billion(ppb)"]  # noqa: E501
        if unit_type not in allowed_values:
            raise ValueError(
                "Invalid value for `unit_type` ({0}), must be one of {1}"  # noqa: E501
                .format(unit_type, allowed_values)
            )

        self._unit_type = unit_type

    @property
    def decimals(self):
        """Gets the decimals of this HbGraphs.  # noqa: E501

        Decimals value in visualization  # noqa: E501

        :return: The decimals of this HbGraphs.  # noqa: E501
        :rtype: str
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this HbGraphs.

        Decimals value in visualization  # noqa: E501

        :param decimals: The decimals of this HbGraphs.  # noqa: E501
        :type: str
        """

        self._decimals = decimals

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HbGraphs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HbGraphs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RollupsummarizationSchemaField1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aggregate_function': 'list[str]',
        'name': 'str'
    }

    attribute_map = {
        'aggregate_function': 'aggregate-function',
        'name': 'name'
    }

    def __init__(self, aggregate_function=None, name=None):  # noqa: E501
        """RollupsummarizationSchemaField1 - a model defined in Swagger"""  # noqa: E501

        self._aggregate_function = None
        self._name = None
        self.discriminator = None

        self.aggregate_function = aggregate_function
        self.name = name

    @property
    def aggregate_function(self):
        """Gets the aggregate_function of this RollupsummarizationSchemaField1.  # noqa: E501


        :return: The aggregate_function of this RollupsummarizationSchemaField1.  # noqa: E501
        :rtype: list[str]
        """
        return self._aggregate_function

    @aggregate_function.setter
    def aggregate_function(self, aggregate_function):
        """Sets the aggregate_function of this RollupsummarizationSchemaField1.


        :param aggregate_function: The aggregate_function of this RollupsummarizationSchemaField1.  # noqa: E501
        :type: list[str]
        """
        if aggregate_function is None:
            raise ValueError("Invalid value for `aggregate_function`, must not be `None`")  # noqa: E501
        allowed_values = ["mean", "count", "sum", "std-dev", "last", "first", "max", "min", "90pct", "95pct", "99pct"]  # noqa: E501
        if not set(aggregate_function).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `aggregate_function` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(aggregate_function) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._aggregate_function = aggregate_function

    @property
    def name(self):
        """Gets the name of this RollupsummarizationSchemaField1.  # noqa: E501

        Name of the field. Should be of pattern [a-z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The name of this RollupsummarizationSchemaField1.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RollupsummarizationSchemaField1.

        Name of the field. Should be of pattern [a-z][a-zA-Z0-9_-]*  # noqa: E501

        :param name: The name of this RollupsummarizationSchemaField1.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RollupsummarizationSchemaField1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RollupsummarizationSchemaField1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class UrlFor(object):
    def __init__(self, hbot):
        self.hbot = hbot
        self.url = hbot.url
        self.config_url = hbot.config_url
        self.grafana_url = hbot.grafana_url

    def system_details(self):
        return "{api}/system-details".format(api=self.url)

    def device(self, device_id=None):
        if device_id is not None:
            return "{api}/device/{device_id}".format(
                api=self.config_url, device_id=device_id)
        else:
            return "{api}/device/".format(
                api=self.config_url)

    def device_facts(self, device_id):
        return "{api}/device/{device_id}/facts".format(
            api=self.config_url, device_id=device_id)

    def devices(self):
        return "{api}/devices".format(api=self.config_url)

    def devices_facts(self):
        return "{api}/devices/facts".format(api=self.config_url)

    def device_group(self, group):
        return "{api}/device-group/{group}".format(api=self.config_url, group=group)

    def device_groups(self):
        return "{api}/device-groups".format(api=self.config_url)

    def device_group_list(self):
        return "{api}/device-group".format(api=self.config_url)

    def network_group(self, group):
        return "{api}/network-group/{group}".format(api=self.config_url, group=group)

    def network_groups(self):
        return "{api}/network-groups".format(api=self.config_url)

    def network_group_list(self):
        return "{api}/network-group".format(api=self.config_url)

    def topic(self, topic_name):
        return "{api}/topic/{topic_name}".format(api=self.config_url,
                                                 topic_name=topic_name)

    def rule(self, topic_name, rule_name):
        return "{api}/topic/{topic_name}/rule/{rule_name}".format(
            api=self.config_url, topic_name=topic_name, rule_name=rule_name)

    def topic(self, topic_name):
        return "{api}/topic/{topic_name}".format(
            api=self.config_url, topic_name=topic_name)

    def topics(self):
        return "{api}/topics".format(api=self.config_url)

    def dg_measurements_list(self, device_id, device_group):
        return "{api}/data/database/table/?device_id={device_id}&device_group_name={dg_name}"\
            .format(api=self.url, device_id=device_id, dg_name=device_group)

    def dg_measurement_fields(self, device_id, device_group, table_name):
        return "{api}/data/database/table/column/?device_id={device_id}&device_group_name={dg_name}" \
               "&table_name={table_name}".format(api=self.url, device_id=device_id,
                                                 dg_name=device_group, table_name=table_name)

    def dg_measurement_tags(self, device_id, device_group, table_name):
        return "{api}/data/database/table/tags/?device_id={device_id}&device_group_name={dg_name}" \
               "&table_name={table_name}".format(api=self.url, device_id=device_id,
                                                 dg_name=device_group, table_name=table_name)

    def ng_measurements_list(self, network_group):
        return "{api}/data/database/table/?network_group_name={network_group}"\
            .format(api=self.url, network_group=network_group)

    def ng_measurement_fields(self, network_group, table_name):
        return "{api}/data/database/table/column/?network_group_name={network_group}&table_name={table_name}"\
            .format(api=self.url, network_group=network_group, table_name=table_name)

    def ng_measurement_tags(self, network_group, table_name):
        return "{api}/data/database/table/tags/?network_group_name={network_group}&table_name={table_name}"\
            .format(api=self.url, network_group=network_group, table_name=table_name)

    def playbook(self, playbook_name):
        return "{api}/playbook/{playbook_name}".format(
            api=self.config_url, playbook_name=playbook_name)

    def playbooks(self):
        return "{api}/playbooks".format(api=self.config_url)

    def health(self):
        return "{api}/health".format(api=self.url)

    def device_health(self, device_id):
        return "{api}/health-tree/{device_id}".format(
            api=self.url, device_id=device_id)

    def device_group_health(self, device_group_name):
        return "{api}/health-tree/device-group/{device_group_name}".format(
            api=self.url, device_group_name=device_group_name)

    def network_group_health(self, network_group_name):
        return "{api}/health-tree/network-group/{network_group_name}".format(
            api=self.url, network_group_name=network_group_name)

    def table(self):
        return "{api}/data/database/table".format(api=self.url)

    def notification(self, notification_name):
        return "{api}/notification/{notification_name}".format(
            api=self.config_url, notification_name=notification_name)

    def notifications(self):
        return "{api}/notifications".format(api=self.config_url)

    def retention_policy(self, retention_policy_name):
        return "{api}/retention-policy/{retention_policy_name}".format(
            api=self.config_url, retention_policy_name=retention_policy_name)

    def retention_policies(self):
        return "{api}/retention-policies".format(api=self.config_url)

    def scheduler(self, name):
        return "{api}/system-settings/scheduler/{name}".format(
            api=self.config_url, name=name)

    def schedulers(self):
        return "{api}/system-settings/schedulers".format(api=self.config_url)

    def destination(self, name):
        return "{api}/system-settings/report-generation/destination/{name}".format(
            api=self.config_url, name=name)

    def destinations(self):
        return "{api}/system-settings/report-generation/destinations".format(
            api=self.config_url)

    def report(self, name):
        return "{api}/system-settings/report-generation/report/{name}".format(
            api=self.config_url, name=name)

    def reports(self):
        return "{api}/system-settings/report-generation/reports".format(
            api=self.config_url)

    def services_device_group(self, device_group_name=None):
        if device_group_name is None:
            return "{api}/services/device-group/".format(api=self.config_url)
        else:
            return "{api}/services/device-group/{device_group_name}".format(
                api=self.config_url, device_group_name=device_group_name)

    def helper_files(self, name):
        return "{api}/files/helper-files/{name}".format(
            api=self.config_url, name=name)

    def ca_profile(self, name):
        return "{api}/profile/security/ca-profile/{name}".format(
            api=self.config_url, name=name)

    def ca_profiles(self):
        return "{api}/profile/security/ca-profiles".format(api=self.config_url)

    def local_certificate(self, name):
        return "{api}/profile/security/local-certificate/{name}".format(
            api=self.config_url, name=name)

    def local_certificates(self):
        return "{api}/profile/security/local-certificates".format(api=self.config_url)

    def ssh_key_profile(self, name):
        return "{api}/profile/security/ssh-key-profile/{name}".format(
            api=self.config_url, name=name)

    def ssh_key_profiles(self):
        return "{api}/profile/security/ssh-key-profiles".format(api=self.config_url)

    def data_store_schema(self, canvas_name, group_name="grafana"):
        "/graph-management/canvas?name=a1"
        return "{api}/data-store/grafana/?key={canvas_name}"\
            .format(api=self.config_url, group_name=group_name, canvas_name=canvas_name)

    def grafana_get_dashboard(self, dashboard_uid):
        return "{grafana_url}/dashboards/uid/{dashboard_uid}"\
            .format(grafana_url=self.grafana_url, dashboard_uid=dashboard_uid)

    def grafana_update_dashboard(self):
        return "{grafana_url}/dashboards/db".format(grafana_url=self.grafana_url)

    def grafana_delete_dashboard(self,dashboard_uid):
        return "{grafana_url}/dashboards/uid/{dashboard_uid}".\
            format(grafana_url=self.grafana_url, dashboard_uid=dashboard_uid)

    def grafana_home_dashboard(self):
        return "{grafana_url}/dashboards/home".format(grafana_url=self.grafana_url)

